%define url_ver %(echo %{version}|cut -d. -f1,2)

%bcond_without dvi
%bcond_without epub

%define major 3
%define api 1.5.0
%define girname     %mklibname %{name}-gir %{api}
%define libname     %mklibname %{name} %{major}
%define develname   %mklibname -d %{name}

Summary:    MATE Document viewer
Name:       atril
Version:    1.26.1
%define subrel 1
Release:    %mkrel 1
License:    GPLv2+ and GFDL
URL:        https://mate-desktop.org/
Group:      Graphical desktop/MATE
Source0:    https://pub.mate-desktop.org/releases/%{url_ver}/%{name}-%{version}.tar.xz
Patch0:     CVE-2023-52076.patch

BuildRequires:  ghostscript
BuildRequires:  itstool
BuildRequires:  libt1lib-devel
BuildRequires:  mate-common
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(ddjvuapi)
BuildRequires:  pkgconfig(gail-3.0)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(gtk+-unix-print-3.0)
%if %{with dvi}
#gw just like xdvi, needed for rendering the fonts
BuildRequires:  pkgconfig(kpathsea)
%endif
BuildRequires:  pkgconfig(libcaja-extension)
BuildRequires:  pkgconfig(libgxps)
BuildRequires:  pkgconfig(libsecret-1)
BuildRequires:  pkgconfig(libspectre)
BuildRequires:  pkgconfig(libtiff-4)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(mate-desktop-2.0)
BuildRequires:  pkgconfig(poppler-glib)
BuildRequires:  pkgconfig(sm)
%if %{with epub}
BuildRequires:  pkgconfig(webkit2gtk-4.1)
%endif
BuildRequires:  pkgconfig(xt)
BuildRequires:  pkgconfig(zlib)
BuildRequires:  xsltproc
BuildRequires:  yelp-tools
BuildRequires:  pkgconfig(synctex)
BuildRequires:  autoconf-archive

Requires:    ghostscript
Requires:    ghostscript-module-X
# for comics support
Requires:    unzip
Requires:    zip
# for org.mate.lockdown schema
Requires:    mate-desktop-schemas >= %{url_ver}

%description
Atril is the MATE Document viewer.
Its supports Portable Document Format (PDF),
PostScript (PS), Encapsulated PostScript (EPS),
DJVU and XPS formats.

%package dvi
Summary:  TeX DVI document support for atril
Group:    Graphical desktop/MATE
#gw just like xdvi, needed for rendering the fonts
Requires: texlive
Requires: %{name} = %{version}-%{release}

%description dvi
This package adds support for displaying .dvi files to atril.
These files are produced by TeX, often using
a macro package like LaTeX.

%package -n %{libname}
Group:    System/Libraries
Summary:  MATE Document viewer library

%description -n %{libname}
This is the MATE Document viewer library, the shared parts of %{name}.

%package -n %{girname}
Summary:  GObject Introspection interface description for %{name}
Group:    System/Libraries
Requires: %{libname} = %{version}-%{release}

%description -n %{girname}
GObject Introspection interface description for %{name}

%package -n %{develname}
Group:    Development/C
Summary:  MATE Document viewer library
Requires: %{libname} = %{version}-%{release}
Requires: %{girname} = %{version}-%{release}
Provides: %{name}-devel = %{version}-%{release}

%description -n %{develname}
This is the MATE Document viewer library, the shared parts of %{name}.

%prep
%autosetup -p1

# build with webkit2gtk-4.1
sed -i "s|webkit2gtk-4.0|webkit2gtk-4.1|g" configure.ac

%build
# To fix overlinking issues needed:
NOCONFIGURE=1 ./autogen.sh
%configure \
    --with-pic                       \
    --disable-static                 \
    --disable-schemas-compile        \
    --enable-thumbnailer             \
    --enable-introspection           \
    --enable-gtk-doc                 \
    --enable-pdf                     \
    --enable-tiff                    \
    --enable-djvu                    \
    --enable-pixbuf                  \
    --enable-comics                  \
    --enable-t1lib=yes               \
    --enable-dvi=%{?with_dvi:yes}%{!?with_dvi:no} \
    --enable-epub=%{?with_epub:yes}%{!?with_epub:no} \
    --enable-xps

%make_build

%install
%make_install

find %{buildroot} -name *.la -delete

%find_lang %{name} --with-gnome --all-name

%files -f %{name}.lang
%doc AUTHORS README*
%license COPYING
%{_bindir}/atril
%{_bindir}/atril-previewer
%{_bindir}/atril-thumbnailer
%{_libexecdir}/atrild
%{_datadir}/metainfo/atril.appdata.xml
%{_datadir}/applications/atril.desktop
%{_datadir}/%{name}/
%{_datadir}/caja/extensions/libatril-properties-page.caja-extension
%{_datadir}/dbus-1/services/*.service
%{_datadir}/glib-2.0/schemas/*.xml
%{_datadir}/thumbnailers/
%{_iconsdir}/hicolor/*/apps/atril*
%{_mandir}/man1/atril*

%dir %{_libdir}/%{name}/%{major}/
%dir %{_libdir}/%{name}/%{major}/backends

%{_libdir}/%{name}/%{major}/backends/libcomicsdocument.so
%{_libdir}/%{name}/%{major}/backends/comicsdocument.%{name}-backend

%{_libdir}/%{name}/%{major}/backends/libdjvudocument.so
%{_libdir}/%{name}/%{major}/backends/djvudocument.%{name}-backend

%if %{with epub}
%{_libdir}/%{name}/%{major}/backends/libepubdocument.so
%{_libdir}/%{name}/%{major}/backends/epubdocument.%{name}-backend
%endif

%{_libdir}/%{name}/%{major}/backends/libpdfdocument.so
%{_libdir}/%{name}/%{major}/backends/pdfdocument.%{name}-backend

%{_libdir}/%{name}/%{major}/backends/libpixbufdocument.so
%{_libdir}/%{name}/%{major}/backends/pixbufdocument.%{name}-backend

%{_libdir}/%{name}/%{major}/backends/libpsdocument.so
%{_libdir}/%{name}/%{major}/backends/psdocument.%{name}-backend

%{_libdir}/%{name}/%{major}/backends/libtiffdocument.so
%{_libdir}/%{name}/%{major}/backends/tiffdocument.%{name}-backend

%{_libdir}/%{name}/%{major}/backends/libxpsdocument.so
%{_libdir}/%{name}/%{major}/backends/xpsdocument.%{name}-backend

# caja extensions
%{_libdir}/caja/extensions-2.0/libatril-properties-page.so

%if %{with dvi}
%files dvi
%{_libdir}/atril/%{major}/backends/libdvidocument.so
%{_libdir}/atril/%{major}/backends/dvidocument.%{name}-backend
%endif

%files -n %{libname}
%{_libdir}/libatrildocument.so.%{major}{,.*}
%{_libdir}/libatrilview.so.%{major}{,.*}

%files -n %{girname}
%{_libdir}/girepository-1.0/AtrilDocument-%{api}.typelib
%{_libdir}/girepository-1.0/AtrilView-%{api}.typelib

%files -n %{develname}
%doc ChangeLog
%doc %{_datadir}/gtk-doc/html/atril
%doc %{_datadir}/gtk-doc/html/libatrildocument-%{api}
%doc %{_datadir}/gtk-doc/html/libatrilview-%{api}
%{_libdir}/libatrildocument.so
%{_libdir}/libatrilview.so
%{_libdir}/pkgconfig/atril*pc
%{_includedir}/atril*
%{_datadir}/gir-1.0/AtrilDocument-%{api}.gir
%{_datadir}/gir-1.0/AtrilView-%{api}.gir


%changelog
* Thu Jun 13 2024 ns80 <ns80> 1.26.1-1.1.mga9
+ Revision: 2072986
- add a patch from Ubuntu for CVE-2023-52076 (mga#33282)

* Tue May 30 2023 kekepower <kekepower> 1.26.1-1.mga9
+ Revision: 1959808
- Update to version 1.26.1

* Mon Dec 12 2022 ns80 <ns80> 1.26.0-4.mga9
+ Revision: 1920974
- rebuild for new libtiff

* Mon Sep 19 2022 wally <wally> 1.26.0-3.mga9
+ Revision: 1890552
- build against webkit2gtk-4.1

* Sat Apr 02 2022 umeabot <umeabot> 1.26.0-2.mga9
+ Revision: 1840439
- Mageia 9 Mass Rebuild

* Mon Aug 09 2021 wally <wally> 1.26.0-1.mga9
+ Revision: 1740908
- new version 1.26.0
+ kekepower <kekepower>
- Update to version 1.24.1
+ danf <danf>
- Switch URLs from http: to https:

* Fri Feb 21 2020 umeabot <umeabot> 1.24.0-2.mga8
+ Revision: 1548011
- Mageia 8 Mass Rebuild

* Tue Feb 11 2020 kekepower <kekepower> 1.24.0-1.mga8
+ Revision: 1488757
- Update to version 1.24.0
+ wally <wally>
- replace deprecated %%configure2_5x

* Tue Dec 10 2019 kekepower <kekepower> 1.22.3-1.mga8
+ Revision: 1465662
- Update to version 1.22.3

* Fri May 10 2019 kekepower <kekepower> 1.22.1-1.mga7
+ Revision: 1397024
- Update to version 1.22.1

* Wed Mar 13 2019 kekepower <kekepower> 1.22.0-2.mga7
+ Revision: 1375491
- Update to version 1.22.0

* Sun Feb 10 2019 wally <wally> 1.20.3-2.mga7
+ Revision: 1365035
- require unzip and zip for comics support
- mention DVI only in dvi sub pkg description
- drop old conflicts and obsoletes

* Sun Dec 16 2018 kekepower <kekepower> 1.20.3-1.mga7
+ Revision: 1341917
- Rediff Patch0
- Update to version 1.20.3

* Sat Dec 01 2018 kekepower <kekepower> 1.20.2-1.mga7
+ Revision: 1337233
- Update to version 1.20.2
- Rolled back to r1295089

* Mon Nov 26 2018 kekepower <kekepower> 1.21.1-1.mga7
+ Revision: 1335504
- Update to version 1.21.1

* Fri Sep 21 2018 umeabot <umeabot> 1.20.0-2.mga7
+ Revision: 1295089
- Mageia 7 Mass Rebuild

* Thu Feb 15 2018 tarakbumba <tarakbumba> 1.20.0-1.mga7
+ Revision: 1201506
- Updated to 1.20.0 version

* Fri Jan 05 2018 tarakbumba <tarakbumba> 1.19.6-1.mga7
+ Revision: 1190408
- Updated to 1.19.6 version

* Thu Dec 14 2017 tarakbumba <tarakbumba> 1.19.5-1.mga7
+ Revision: 1182602
- Updated to 1.19.5 version

* Sun Oct 29 2017 tarakbumba <tarakbumba> 1.19.4-1.mga7
+ Revision: 1174794
- Update to 1.19.4 version

* Thu Aug 24 2017 wally <wally> 1.18.1-1.mga7
+ Revision: 1147473
- new version 1.18.1

* Thu Jul 27 2017 neoclust <neoclust> 1.18.0-2.mga7
+ Revision: 1131332
- Add Patch from debian to fix CVE-2017-1000083 (mga#21326)

* Tue Mar 14 2017 tarakbumba <tarakbumba> 1.18.0-1.mga6
+ Revision: 1092602
- Update to 1.18.0 version
- Update to 1.17.1 version
- Update to 1.17.0 version

* Sun Dec 25 2016 wally <wally> 1.16.0-1.mga6
+ Revision: 1077285
- new version 1.16.0
- build with gtk3
- move backends and caja extension to main pkg
- tag devel docs as such

* Mon Nov 28 2016 luigiwalser <luigiwalser> 1.14.1-3.mga6
+ Revision: 1070607
- rebuild for poppler

* Sat Aug 13 2016 luigiwalser <luigiwalser> 1.14.1-2.mga6
+ Revision: 1046166
- test rebuild for poppler

* Sun May 22 2016 tarakbumba <tarakbumba> 1.14.1-1.mga6
+ Revision: 1017861
- Update to 1.14.1 version

* Thu Apr 14 2016 tarakbumba <tarakbumba> 1.14.0-1.mga6
+ Revision: 1001513
- Update to 1.14.0 version

* Fri Feb 26 2016 tarakbumba <tarakbumba> 1.13.1-1.mga6
+ Revision: 979316
- Update to 1.13.1 version

* Mon Feb 08 2016 tarakbumba <tarakbumba> 1.13.0-1.mga6
+ Revision: 950615
- Update to 1.13.0 version

* Fri Dec 18 2015 tarakbumba <tarakbumba> 1.12.2-1.mga6
+ Revision: 911775
- Update to 1.12.2 version

* Sun Dec 06 2015 tarakbumba <tarakbumba> 1.12.1-1.mga6
+ Revision: 908515
- Update to 1.12.1 version

* Sun Nov 08 2015 tarakbumba <tarakbumba> 1.12.0-1.mga6
+ Revision: 899215
-Update to 1.12.0 version

* Tue Sep 01 2015 wally <wally> 1.10.2-1.mga6
+ Revision: 871978
- new version 1.10.2

* Sun Jun 28 2015 wally <wally> 1.10.0-2.mga6
+ Revision: 847140
- add requires for gir pkg to devel pkg

* Mon Jun 22 2015 tarakbumba <tarakbumba> 1.10.0-1.mga6
+ Revision: 839829
- Update to 1.10.0 version

* Thu Nov 20 2014 tarakbumba <tarakbumba> 1.8.1-3.mga5
+ Revision: 797955
- Add cherrypicked bugfix patches from upstream
- Bump rel

* Wed Oct 15 2014 umeabot <umeabot> 1.8.1-2.mga5
+ Revision: 742213
- Second Mageia 5 Mass Rebuild

* Tue Oct 07 2014 tarakbumba <tarakbumba> 1.8.1-1.mga5
+ Revision: 737446
- Update to 1.8.1 version
- Use autosetup macro in specfile

* Tue Sep 16 2014 umeabot <umeabot> 1.8.0-2.mga5
+ Revision: 678031
- Mageia 5 Mass Rebuild

* Wed Mar 05 2014 tarakbumba <tarakbumba> 1.8.0-1.mga5
+ Revision: 600116
- Updated to version 1.8.0

* Mon Mar 03 2014 tarakbumba <tarakbumba> 1.7.90-5.mga5
+ Revision: 599128
- Require mate-desktop-schema package instead of mate-desktop package

* Sun Mar 02 2014 wally <wally> 1.7.90-4.mga5
+ Revision: 598620
- require mate-desktop for 'org.mate.lockdown' settings schema

* Sat Mar 01 2014 tarakbumba <tarakbumba> 1.7.90-3.mga5
+ Revision: 598429
- Fix obsoletes and provides for dvi extension and devel package

* Sat Mar 01 2014 tarakbumba <tarakbumba> 1.7.90-2.mga5
+ Revision: 598362
- Fix obsoletes and provides tags

* Sat Mar 01 2014 tarakbumba <tarakbumba> 1.7.90-1.mga5
+ Revision: 598066
- imported package atril

